<?php
#
# Script         Smiley
# Copyright      2009 OEM Scripts
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
# Autor          Denny Schlesinger
# OEM Scripts    http://oemscripts.com
#
# $Id: $
#

/**********************   Smiley  **********************/

if (!function_exists('__autoload')) {
    function __autoload($class_name) { 
        require_once $class_name . '.php';
    }
}


class Smiley implements SmileyInterface {
    private $smiley= array();         // smiley strings
    private $path;                    // path to smileys

    public function __construct($path = '') {
    
        $this->path = $path;
    
        $this->smiley[':)'] = array('smile.gif','smile');
        $this->smiley[':('] = array('frown.gif','frown');
        $this->smiley[':o'] = array('redface.gif','embarrasment');
        $this->smiley[';)'] = array('wink.gif','wink');
        $this->smiley[':banana'] = array('banana.gif','Banana');
        $this->smiley[':crying'] = array('bawling.gif','crying');
        $this->smiley[':beer'] = array('beer.gif','beer');
        $this->smiley[':D'] = array('biggrin.gif','big_grin');
        $this->smiley[':buck'] = array('buck.gif','buck');
        $this->smiley[':cool:'] = array('cool.gif','cool');
        $this->smiley[':dgrin'] = array('dgrin.gif','devil_grin');
        $this->smiley[':eek'] = array('eek.gif','eek');
        $this->smiley[':lol'] = array('laugh.gif','laugh');
        $this->smiley[':rolleyes:'] = array('rolleyes.gif','roll eyes (sarcastic)');
        $this->smiley[':nuts'] = array('nuts.gif','nuts');
        $this->smiley[':rofl'] = array('rolling_smile.gif','rofl');
        $this->smiley[':hammer'] = array('smash.gif','hammer');
        $this->smiley[':thumb'] = array('thumb.gif','thumb');
        $this->smiley[':tongue'] = array('tongue.gif','stick out tongue');
        $this->smiley[':wave'] = array('wavey.gif','wave');
        $this->smiley[':unhappy'] = array('unhappy.gif','unhappy');
    }
        
    public function image($value) {
        if ($size = @getimagesize("{$this->path}{$value[0]}")) {
            $image  = "<img src='{$this->path}{$value[0]}' ";
            $image .= "alt='{$value[1]}' ";
            $image .= "title='{$value[1]}' ";
            $image .= $size[3] . ">";
            return $image;
        } else {
            return FALSE;
        }
    }

    public function render($text) {
        foreach ($this->smiley AS $key=>$value) {
            if ($image = self::image($value)) {
                $text = str_replace ($key,  $image, $text);
            } else {
            echo "error {$value[0]} <br>";
            }
        }
        return $text;
    }

    public function test() {
        $i = 0;
        $j = 0;
        foreach ($this->smiley AS $key=>$value) {
            if (!$size = @getimagesize("{$this->path}{$value[0]}")) {
                echo "error {$value[0]} missing<br>\n";
                $i++;
            }
            $j++;
        }
        if (!$i)
        echo "{$j} images found in <strong>'{$this->path}'</strong> directory<br>\n";
    }

    public function listing($columns = '') {
        if ($columns == '') { $columns = 2; }
        $z = (count($this->smiley) % $columns);
        $col = 0;
        $list  = "<div class='smilies'>\n";
        $list .= "<div class='legend'>Smilies</div>\n";
        $list .= "<div class='table'>\n";
        $list .= "  <div class='row'>\n";
        // column headings
        for ($i=0; $i<$columns; $i++) {
            $list .= "    <div class='cell heading'>";
            $list .= "token";
            $list .= "</div>\n";
            $list .= "    <div class='cell heading'>";
            $list .= "image";
            $list .= "</div>\n";
            $list .= "    <div class='cell heading'>";
            $list .= "title";
            $list .= "</div>\n";
        }        
        $list .= "</div>\n";
        // build rows
        $shade = '';
        foreach ($this->smiley AS $token => $value) {
            $image = self::image($value);
            if ($col++ == 0) {
                $list .= "  <div class='row{$shade}'>\n";
                if ($shade == '') {
                    $shade = ' shade';
                } else {
                    $shade = '';
                }
            } 
            $list .= "    <div class='cell'>";
            $list .= $token;
            $list .= "</div>\n";
            $list .= "    <div class='cell'>";
            $list .= $image;
            $list .= "</div>\n";
            $list .= "    <div class='cell'>";
            $list .= $value[1];
            $list .= "</div>\n";
            if ($col == $columns) {
                $list .= "  </div>\n";
                $col = 0;
            } 
        }
        // pad incomplete row
        while ($col AND ++$col <= $columns) {
            $list .= "    <div class='cell'></div><div class='cell'></div><div class='cell'></div>\n";
        }
        // close incomplete row
        if (count($this->smiley) % $columns != 0) {
            $list .= "  </div>\n";
        }
        // close table
        $list .=  "</div>\n";
        $list .=  "</div>\n";
        return $list;
    }

}

?>
